[−][src]Struct grep_cli::ParseSizeError
An error that occurs when parsing a human readable size description.
This error provides a end user friendly message describing why the description coudln't be parsed and what the expected format is.